@@ -61,6 +61,13 @@
         <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
         <translation type="unfinished">यी भुक्तानी गर्नका लागि तपाइका बिट्कोइन ठेगानाहरू हुन्। सिक्काहरू पठाउनुअघि रकम र प्राप्त गर्ने ठेगाना जाँच गर्नुहोस।</translation>
     </message>
+    <message>
+        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
+Signing is only possible with addresses of the type 'legacy'.</source>
+        <translation type="unfinished">यी तपाईंका भुक्तानी प्राप्त गर्ने बिटकोईन ठेगानाहरू हुन्। नयाँ ठेगाना बनाउनको लागि, 'प्राप्त' ट्याबमा रहेको 'नयाँ प्राप्त गर्ने ठेगाना सिर्जना गर्नुहोस्' बटनको प्रयोग गर्नुहोस्। 
+हस्ताक्षर केवल 'लेगेसी' प्रकारका ठेगानाहरूमा मात्र सम्भव छ।
+ </translation>
+    </message>
     <message>
         <source>&amp;Copy Address</source>
         <translation type="unfinished">ठेगाना कपी गर्नुहोस्</translation>
@@ -157,6 +164,10 @@
         <source>Confirm wallet encryption</source>
         <translation type="unfinished">वालेट इन्क्रिप्सन सुनिश्चित गर्नुहोस</translation>
     </message>
+    <message>
+        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
+        <translation type="unfinished">यदि तपाईंले आफ्नो वालेटलाई इन्क्रिप्ट  गरेर पासफ्रेज बिर्सनु भयो भने , &lt;b&gt; तपाईंले आफ्ना सबै बिटकोइनहरू गुमाउनुहुनेछ &lt;/b&gt; ।</translation>
+    </message>
     <message>
         <source>Are you sure you wish to encrypt your wallet?</source>
         <translation type="unfinished">के तपाइँ तपाइँको वालेट ईन्क्रिप्ट गर्न निश्चित हुनुहुन्छ?</translation>
@@ -189,6 +200,10 @@
         <source>Your wallet is now encrypted. </source>
         <translation type="unfinished">अब वालेट इन्क्रिप्ट भएको छ।</translation>
     </message>
+    <message>
+        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
+        <translation type="unfinished">महत्वपूर्ण: तपाईंले आफ्नो वालेट फाइलको कुनै पनि पुराना ब्याकअपहरू नयाँ बनाइएको र इन्क्रिप्ट गरिएको वालेट फाइलले प्रतिस्थापन गर्नुपर्छ। सुरक्षा कारणले, इन्क्रिप्ट नगरिएको वालेट फाइलका पुराना ब्याकअपहरू तपाईंले नयाँ, इन्क्रिप्ट गरिएको वालेट प्रयोग गर्न थालेपछि बेकार हुनेछन्।</translation>
+    </message>
     <message>
         <source>Wallet encryption failed</source>
         <translation type="unfinished">वालेट इन्क्रिप्सन असफल </translation>
@@ -209,6 +224,10 @@
         <source>The passphrase entered for the wallet decryption was incorrect.</source>
         <translation type="unfinished">वालेट डिक्रिप्शनको लागि प्रविष्ट गरिएको पासफ्रेज गलत थियो।</translation>
     </message>
+    <message>
+        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
+        <translation type="unfinished">वालेट डिक्रिप्सनका लागि प्रविष्ट गरिएको पासफ्रेज गलत छ। यसमा शून्य क्यारेक्टर (जस्तै - शून्य बाइट) समावेश छ। यदि पासफ्रेज यस सफ्टवेयरको संस्करण २५.० भन्दा पहिले सेट गरिएको थियो भने, पहिलो शून्य क्यारेक्टरसम्मका क्यारेक्टरहरू मात्र प्रयोग गरेर पुन: प्रयास गर्नुहोस्, तर पहिलो शून्य क्यारेक्टरलाई समावेश नगर्नुहोस्। यदि यो सफल भयो भने, भविष्यमा यो समस्या नदोहोरियोस् भन्नका लागि नयाँ पासफ्रेज सेट गर्नुहोस्।</translation>
+    </message>
     <message>
         <source>Wallet passphrase was successfully changed.</source>
         <translation type="unfinished">वालेट पासफ्रेज सफलतापूर्वक परिवर्तन गरियो।</translation>
@@ -217,6 +236,10 @@
         <source>Passphrase change failed</source>
         <translation type="unfinished">पासफ्रेज परिवर्तन असफल भयो</translation>
     </message>
+    <message>
+        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
+        <translation type="unfinished">वालेट डिक्रिप्सनका लागि प्रविष्ट गरिएको पासफ्रेज गलत छ। यसमा शून्य क्यारेक्टर (जस्तै - शून्य बाइट) समावेश छ। यदि पासफ्रेज यस सफ्टवेयरको संस्करण 25.0 भन्दा पहिले सेट गरिएको थियो भने, पहिलो शून्य क्यारेक्टरसम्मका क्यारेक्टरहरू मात्र प्रयोग गरेर पुन: प्रयास गर्नुहोस्, तर पहिलो शून्य क्यारेक्टरलाई समावेश नगर्नुहोस्।</translation>
+    </message>
     <message>
         <source>Warning: The Caps Lock key is on!</source>
         <translation type="unfinished">चेतावनी: क्याप्स लक कीप्याड अन छ!</translation>
@@ -525,6 +548,10 @@
     </context>
 <context>
     <name>CreateWalletDialog</name>
+    <message>
+        <source>You are one step away from creating your new wallet!</source>
+        <translation type="unfinished">तपाईं आफ्नो नयाँ वालेट सिर्जना गर्नबाट एक कदम मात्र टाढा हुनुहुन्छ!</translation>
+    </message>
     <message>
         <source>Wallet Name</source>
         <translation type="unfinished">वालेट को नाम</translation>
@@ -641,6 +668,10 @@
         <source>&amp;Main</source>
         <translation type="unfinished">&amp;मुख्य</translation>
     </message>
+    <message>
+        <source>Full path to a %1 compatible script (e.g. C:\Downloads\hwi.exe or /Users/you/Downloads/hwi.py). Beware: malware can steal your coins!</source>
+        <translation type="unfinished">%1 अनुकूल स्क्रिप्टको पूर्ण पथ (उदाहरणका लागि, C:\Downloads\hwi.exe वा /Users/you/Downloads/hwi.py) प्रविष्ट गर्नुहोस्। सावधान : मालवेयरले तपाईंका सिक्काहरू चोरी गर्न सक्छ!</translation>
+    </message>
     <message>
         <source>&amp;Network</source>
         <translation type="unfinished">&amp;नेटवर्क</translation>
@@ -731,6 +762,17 @@
         <source>Close</source>
         <translation type="unfinished">बन्द गर्नुहोस्</translation>
     </message>
+    <message>
+        <source>Transaction broadcast successfully! Transaction ID: %1</source>
+        <translation type="unfinished">कारोबार सफलतापूर्वक प्रसारण गरियो! कारोबारआईडी: %1</translation>
+    </message>
+    </context>
+<context>
+    <name>PaymentServer</name>
+    <message>
+        <source>URI cannot be parsed! This can be caused by an invalid Bitcoin address or malformed URI parameters.</source>
+        <translation type="unfinished">URI पढ्न सकिएन! यस्तो आमान्य बिटकोइन ठेगाना वा गलत URI प्यारामिटरहरूका कारण हुन सक्छ</translation>
+    </message>
     </context>
 <context>
     <name>PeerTableModel</name>
@@ -811,10 +853,18 @@
     </context>
 <context>
     <name>SendCoinsDialog</name>
+    <message>
+        <source>Insufficient funds!</source>
+        <translation type="unfinished">अपर्याप्त कोष!</translation>
+    </message>
     <message>
         <source>Hide</source>
         <translation type="unfinished">लुकाउनुहोस्</translation>
     </message>
+    <message>
+        <source>Transaction creation failed!</source>
+        <translation type="unfinished">कारोबार सिर्जना सफल भएन ।</translation>
+    </message>
     <message numerus="yes">
         <source>Estimated to begin confirmation within %n block(s).</source>
         <translation type="unfinished">
@@ -990,10 +1040,6 @@
         <source>Corrupted block database detected</source>
         <translation type="unfinished">क्षति पुगेको ब्लक डाटाबेस फेला पर</translation>
     </message>
-    <message>
-        <source>Do you want to rebuild the block database now?</source>
-        <translation type="unfinished">तपाईं अहिले ब्लक डेटाबेस पुनर्निर्माण गर्न चाहनुहुन्छ ?</translation>
-    </message>
     <message>
         <source>Unable to bind to %s on this computer. %s is probably already running.</source>
         <translation type="unfinished">यो कम्प्युटरको %s मा बाँध्न सकिएन । %s सम्भवित रूपमा पहिलैबाट चलिरहेको छ ।</translation>
